==> ec2-0.27.0-sources.jar: software/amazon/awscdk/services/ec2/AmazonLinuxImage.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Selects the latest version of Amazon Linux
 * 
 * The AMI ID is selected using the values published to the SSM parameter store.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-03-28T21:35:50.667Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.AmazonLinuxImage")
public class AmazonLinuxImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImageSource {
    protected AmazonLinuxImage(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public AmazonLinuxImage(@javax.annotation.Nullable final software.amazon.awscdk.services.ec2.AmazonLinuxImageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.of(props).toArray());
    }
    public AmazonLinuxImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Return the image to use in the given context
     */
    @Override
    public software.amazon.awscdk.services.ec2.MachineImage getImage(final software.amazon.awscdk.Construct scope) {
        return this.jsiiCall("getImage", software.amazon.awscdk.services.ec2.MachineImage.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")).toArray());
    }
}

==> ec2-0.29.0-sources.jar: software/amazon/awscdk/services/ec2/AmazonLinuxImage.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Selects the latest version of Amazon Linux.
 * 
 * The AMI ID is selected using the values published to the SSM parameter store.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-04-24T21:03:46.506Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.AmazonLinuxImage")
public class AmazonLinuxImage extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImageSource {
    protected AmazonLinuxImage(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public AmazonLinuxImage(@javax.annotation.Nullable final software.amazon.awscdk.services.ec2.AmazonLinuxImageProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }
    public AmazonLinuxImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Return the image to use in the given context.
     */
    @Override
    public software.amazon.awscdk.services.ec2.MachineImage getImage(final software.amazon.awscdk.Construct scope) {
        return this.jsiiCall("getImage", software.amazon.awscdk.services.ec2.MachineImage.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }
}
